@@ -113,11 +113,11 @@ class CSharpLexer(RegexLexer):
                 (cs_ident, Name),
             ],
             'class': [
-                (r'[a-zA-Z_][a-zA-Z0-9_]*', Name.Class, '#pop')
+                (cs_ident, Name.Class, '#pop')
             ],
             'namespace': [
                 (r'(?=\()', Text, '#pop'), # using (resource)
-                (r'[a-zA-Z_][a-zA-Z0-9_.]*', Name.Namespace, '#pop')
+                ('(' + cs_ident + r'|\.)+', Name.Namespace, '#pop')
             ]
         }
 
